#!/bin/sh
#
# Ken-Ichi Ishikawa
# for ASLFT2010@TATA (2010/03/12-)
#
# ($Id: RUN.sh,v 1.3 2011/03/03 08:04:57 ishikawa Exp $)
#

prog=two_site_scalar_hmc
input=ISING_PARAM
iseed=1987654
tau=2.0
nmd=4
ntherm=1000
nskip=100
nsample=100000

for b in 0.1 0.2 0.4 0.7 0.9
do


#########################################
# Create Input parameter file
#########################################
  jseed=`echo $iseed $b | awk '{printf("%d",$1+$2*10)}'`
  echo ${b}d0                  >  $input
  echo $jseed                  >> $input
  echo $ntherm $nsample $nskip >> $input
  echo $tau $nmd               >> $input

  output="b"${b}"_N"${nsample}".dat"

#########################################
# Run program
#########################################
  ./$prog > $output

#########################################
# Analyze ensemble
#########################################
  ############################
  # Make state weight
  # histogram
  ############################
  hist="hist_b"${b}"_N"${nsample}".dat"

  echo "# state histogram" > $hist
  if [ x$b = x0.1 ]; then
    range="-3 3"
  fi
  if [ x$b = x0.2 ]; then
    range="-3 3"
  fi
  if [ x$b = x0.4 ]; then
    range="-4 4"
  fi
  if [ x$b = x0.7 ]; then
    range="-5 5"
  fi
  if [ x$b = x0.9 ]; then
    range="-8 8"
  fi
  sed '/#/d' $output | awk '{print $1,$2,$3}' | ./histogram $range >> $hist

  ############################
  # Statistical analysis on
  # spin observables
  ############################
  save="save_b"${b}"_N"${nsample}".dat"
  scor="scor_b"${b}"_N"${nsample}".dat"

  sed '/#/d' $output | awk '{print $1,$4}' > $save
  sed '/#/d' $output | awk '{print $1,$5}' > $scor

  savej="save_b"${b}"_N"${nsample}"_jack.dat"
  scorj="scor_b"${b}"_N"${nsample}"_jack.dat"

  echo "# expectation value of spin averaging"   > $savej
  ./jackbin $save >> $savej
  
  echo "# expectation value of spin correlation" > $scorj
  ./jackbin $scor >> $scorj

done
